#!/usr/bin/env perl

use strict;
use warnings;

our $pd_subdomain    = 'cub-uanic-odesk-pd1';
our $pd_user         = 'cub-uanic+pd1@odesk.com';
our $pd_password     = 'HrS7CR82nU9-eL_nXFtuDRrx';
our $pd_service_key  = '2e548200d05d012f6b1022000afc2393';
our $pd_incident_key = 'HTTP/srv01.odesk.com';
our $pd_schedule_id  = 'PK886K8';

